import Color from 'color';
var darken = function (percent, color) {
    return Color(color)
        .darken(percent)
        .hex();
};
var lighten = function (percent, color) {
    return Color(color)
        .lighten(percent)
        .hex();
};
var primary = '#00AEEF';
var secondary = '#2A506F';
var tertiary = '#527699';
var quartenary = '#F8F9FD';
var danger = '#FF423D';
var warning = '#FCA321';
var success = '#1AC135';
var info = '#1496E1';
var colors = {
    primary: {
        main: primary,
        light: lighten(0.1, primary),
        dark: darken(0.1, primary),
    },
    secondary: {
        main: secondary,
        light: lighten(0.1, secondary),
        dark: darken(0.1, secondary),
    },
    tertiary: {
        main: tertiary,
        light: lighten(0.1, tertiary),
        dark: darken(0.1, tertiary),
    },
    quartenary: {
        main: quartenary,
        light: lighten(0.1, quartenary),
        dark: darken(0.1, quartenary),
    },
    danger: {
        main: danger,
        semilight: lighten(0.2, danger),
        light: lighten(0.55, danger),
        dark: darken(0.2, danger),
    },
    warning: {
        main: warning,
        semilight: lighten(0.2, warning),
        light: lighten(0.7, warning),
        dark: darken(0.2, warning),
    },
    success: {
        main: success,
        semilight: lighten(0.22, success),
        light: lighten(1.25, success),
        dark: darken(0.2, success),
    },
    info: {
        main: info,
        semilight: lighten(0.27, info),
        light: lighten(1, info),
        dark: darken(0.2, info),
    },
    text: {
        main: '#3c3e42',
        light: '#8f9297',
        dark: '#1c1d1e',
    },
    statusIdle: {
        main: '#89c683',
    },
    statusConfiguring: {
        main: '#ffb25e',
    },
    statusUpdating: {
        main: '#75C5F5',
    },
    statusPostProvisioning: {
        main: '#aa96d5',
    },
    statusOffline: {
        main: '#fd7c7c',
    },
    statusInactive: {
        main: '#d3d6db',
    },
    gray: {
        main: '#c6c8c9',
        light: '#f4f4f4',
        dark: '#9f9f9f',
    },
};
var defaultControlHeight = 36;
var emphasizedControlHeight = 48;
export var breakpoints = ['32em', '48em', '64em', '80em'];
export var space = [
    0,
    4,
    8,
    16,
    defaultControlHeight,
    emphasizedControlHeight,
    128,
];
export var fontSizes = [12, 14, 16, 20, 24, 32, 48, 64, 72, 96];
export var weights = [400, 700];
export var radius = 3;
export var font = "'Nunito', Arial, sans-serif";
export var titleFont = "CircularStd, Arial, sans-serif";
export var monospace = "'Ubuntu Mono', 'Courier New', monospace";
export default {
    breakpoints: breakpoints,
    space: space,
    fontSizes: fontSizes,
    weights: weights,
    font: font,
    titleFont: titleFont,
    monospace: monospace,
    colors: colors,
    radius: radius,
    global: {
        font: {
            family: font,
            size: '14px',
            height: 1.5,
        },
        control: {
            disabled: {
                opacity: 0.4,
            },
            border: {
                radius: '4px',
                color: colors.quartenary.dark,
            },
        },
        colors: {
            focus: '#73AAF5',
        },
        selected: {
            background: colors.primary.main,
        },
        hover: {
            background: {
                color: colors.quartenary.main,
                opacity: 1,
            },
            color: {
                dark: 'inherit',
                light: 'inherit',
            },
        },
        active: {
            background: {
                color: colors.quartenary.main,
                opacity: 1,
            },
            color: {
                dark: 'inherit',
                light: 'inherit',
            },
        },
        drop: {
            border: {
                radius: '4px',
            },
            zIndex: 45,
            extend: "color: " + colors.secondary.main + "; border: 1px solid " + colors.quartenary.dark + ";",
        },
    },
    button: {
        height: '38px',
        font: {
            weight: 500,
        },
        border: {
            width: '1px',
            radius: '20px',
            color: colors.text.main,
        },
        padding: {
            horizontal: '30px',
        },
    },
    radioButton: {
        border: {
            width: '1px',
        },
        check: {
            color: {
                dark: 'white',
                light: 'white',
            },
        },
        icon: { size: '12px' },
        gap: '10px',
        size: '20px',
    },
    select: {
        icons: {
            color: colors.secondary.main,
        },
        control: {
            extend: "color: " + colors.secondary.main,
        },
    },
    layer: {
        container: {
            zIndex: 40,
        },
        zIndex: 30,
    },
    text: {
        medium: {
            size: '14px',
            height: '1.5',
        },
    },
    tab: {
        extend: 'border: none;',
        color: colors.primary.main,
    },
};
